package main

import (
	"time"

	"gitlab.informatika.org/k-01-11/graduit-be/src/database"
	"gitlab.informatika.org/k-01-11/graduit-be/src/models"
)

func addDosen(name, npwp string) string {
	db := database.GetInstance()
	newUser := models.Users{}

	db.Create(&newUser)

	newDosen := models.Dosen{Name: name, NPWP: npwp, IdDosen: newUser.Id}
	db.Create(&newDosen)

	return newDosen.IdDosen
}

func addMahasiswa(name, nim, iddosen string) string {
	db := database.GetInstance()
	newUser := models.Users{}

	db.Create(&newUser)

	newMhs := models.Mahasiswa{Name: name, NIM: nim, IdMahasiswa: newUser.Id, IdDosen: iddosen}
	db.Create(&newMhs)

	return newMhs.IdMahasiswa
}

func addTopik(judul, deskripsi, idDosen string) string {
	db := database.GetInstance()
	newTopik := models.Topik{Judul: judul, Deskripsi: deskripsi, IdDosen: idDosen}

	db.Create(&newTopik)

	return newTopik.Id
}

func addPendaftaran(idtopik, idmhs, iddosen string) string {
	newStatus := true
	timeNow := time.Now()
	tenDaysLater := timeNow.Add(10 * 24 * time.Hour)

	db := database.GetInstance()
	newTopik := models.Pendaftaran{IdTopik: idtopik, IdMahasiswa: idmhs, IdDosen: iddosen, Status: &newStatus, InterviewAt: &timeNow, DecidedAt: &tenDaysLater}

	db.Create(&newTopik)

	return newTopik.Id
}

func addUsulanJudul(judul, idpendaftaran string, status bool) string {
	db := database.GetInstance()
	newTopik := models.UsulanJudul{Judul: judul, IdPendaftaran: idpendaftaran, Status: &status}

	db.Create(&newTopik)

	return newTopik.Id
}

func acceptJudul(idjudul, idpendaftaran string) {
	newStatus := true
	timeNow := time.Now()
	tenDaysLater := timeNow.Add(10 * 24 * time.Hour)

	db := database.GetInstance()
	db.Save(&models.UsulanJudul{Id: idjudul, Status: &newStatus})
	db.Save(&models.Pendaftaran{Id: idpendaftaran, Status: &newStatus, DecidedAt: &tenDaysLater, InterviewAt: &timeNow})
}

func main() {
	// create 2 dosen
	idDosen1 := addDosen("I Gusti Bagus Baskara Nugraha, S.T., M.T., Ph.D.", "0024017606")
	idDosen2 := addDosen("Dr. Eng. Ayu Purwarianti, S.T, M.T.", "0024017607")

	// create 2 mahasiswa
	idMhs1 := addMahasiswa("Ariel Jovananda", "13521086", idDosen1)
	idMhs2 := addMahasiswa("Lidya Rahmatul Fitri", "10023485", idDosen2)

	// create topik for each dosen
	idTopik1 := addTopik("Pengembangan Sistem Pendeteksi Anomali Otomatis Menggunakan Deep Learning", "Topik ini berkaitan dengan pengembangan sistem yang dapat mendeteksi anomali secara otomatis dalam data. Anomali seringkali menjadi tanda-tanda yang penting dalam berbagai konteks, seperti deteksi kecurangan dalam transaksi keuangan atau pengawasan mesin dalam lingkungan industri. Dengan menggunakan teknik-teknik deep learning, termasuk Convolutional Neural Networks (CNNs) atau Recurrent Neural Networks (RNNs), tugas akhir ini akan memfokuskan pada pengembangan model yang mampu secara efektif mengenali pola anomali dari data yang kompleks dan berdimensi tinggi.", idDosen1)
	idTopik2 := addTopik("Pengembangan Sistem Rekomendasi Berbasis AI untuk E-Commerce", "Topik ini bertujuan untuk mengembangkan sistem rekomendasi yang cerdas untuk platform e-commerce. Sistem rekomendasi adalah salah satu aplikasi utama dari kecerdasan buatan yang telah terbukti meningkatkan retensi pelanggan dan meningkatkan penjualan dalam industri e-commerce. Tugas akhir ini akan melibatkan penggunaan teknik-teknik seperti collaborative filtering, content-based filtering, dan deep learning untuk membangun model yang dapat memberikan rekomendasi produk yang relevan dan personal bagi setiap pengguna, meningkatkan pengalaman belanja online dan konversi penjualan.", idDosen2)

	idPendaftaran1 := addPendaftaran(idTopik1, idMhs1, idDosen1)
	idPendaftaran2 := addPendaftaran(idTopik2, idMhs2, idDosen2)

	// create 2 judul for each topik
	addUsulanJudul("Implementasi Convolutional Neural Networks untuk Deteksi Anomali pada Citra Medis", idPendaftaran1, true)
	addUsulanJudul("Pengembangan Model Deep Learning untuk Deteksi Anomali pada Data Sensor IoT", idPendaftaran1, false)

	addUsulanJudul("Peningkatan Kinerja Sistem Rekomendasi Berbasis AI dengan Metode Ensemble Learning", idPendaftaran2, true)
	addUsulanJudul("Personalisasi Rekomendasi Produk dalam E-Commerce Menggunakan Representasi Laten yang Dalam", idPendaftaran2, false)
}
