package repository

import (
	// "time"

	"github.com/google/uuid"
	"gitlab.informatika.org/k-01-11/graduit-be/src/module/batch_seminar/entity"
	"gorm.io/gorm"
)

type BatchSeminarRepo struct {
	DBWrite *gorm.DB
	DBRead  *gorm.DB
}

func NewBatchSeminarRepository(dbWrite *gorm.DB, dbRead *gorm.DB) *BatchSeminarRepo {
	return &BatchSeminarRepo{
		DBWrite: dbWrite,
		DBRead:  dbRead,
	}
}

func (repo *BatchSeminarRepo) NewBatchSeminar(batchseminar entity.BatchSeminar) (output entity.BatchSeminar, err error) {
	batchseminar.IDBatch = uuid.New().String()
	result := repo.DBWrite.Create(&batchseminar)
	if result.Error != nil {
		return entity.BatchSeminar{}, result.Error
	}
	return batchseminar, nil
}

func (repo *BatchSeminarRepo) GetSeminarBatches() (output []entity.BatchSeminar, err error) {
	var batches []entity.BatchSeminar
	result := repo.DBRead.Find(&batches)
	if result.Error != nil {
		return nil, err
	}
	return batches, nil
}

func (repo *BatchSeminarRepo) DeleteBatchSeminar(id string) (entity.BatchSeminar, error) {
	batch := entity.BatchSeminar{IDBatch: id}
	err := repo.DBWrite.Delete(&batch).Error

	if err != nil {
		return batch, err
	}

	return batch, err
}
