package transport

import (
	"fmt"
	"net/http"

	"github.com/labstack/echo"
	"gitlab.informatika.org/k-01-11/graduit-be/src/module/batch_sidang/config"
	"gitlab.informatika.org/k-01-11/graduit-be/src/module/batch_sidang/entity"
	"gitlab.informatika.org/k-01-11/graduit-be/src/module/batch_sidang/internal/repository"
	"gitlab.informatika.org/k-01-11/graduit-be/src/module/batch_sidang/internal/usecase"
	"gitlab.informatika.org/k-01-11/graduit-be/src/utils"
)

type AdminBatchSidangHandler struct {
	batchSidangUsecase usecase.BatchSidangUsecase
}

func NewAdminBatchSidangHandler(cfg config.BatchSidangTransportConfig) *AdminBatchSidangHandler {
	batchSidangRepository := repository.NewBatchSidangRepository(cfg.DBWrite, cfg.DBRead)
	batchSidangUsecase := usecase.NewBatchSidangUseCase(batchSidangRepository)

	return &AdminBatchSidangHandler{
		batchSidangUsecase: batchSidangUsecase,
	}

}

func (t *AdminBatchSidangHandler) MountAdmin(group *echo.Group) {
	group.GET("/batch-sidang", t.AddBatchSidang)
	group.GET("/batch-sidang-get", t.GetBatchSidang)
	group.GET("/batch-sidang-delete", t.DeleteBatch)
}

func (t *AdminBatchSidangHandler) AddBatchSidang(c echo.Context) error {
	batch := new(entity.BatchSidang)

	start := c.QueryParam("startDate")
	end := c.QueryParam("endDate")

	target := &entity.BatchSidang{
		StartDate: start,
		EndDate:   end,
	}

	if err := c.Bind(batch); err != nil {
		return c.JSON(http.StatusBadRequest, utils.ResponseDetailOutput(false, http.StatusBadRequest, err.Error(), nil))
	}

	fmt.Println(*batch)
	newBatch, err := t.batchSidangUsecase.AddBatchSidang(*target)
	if err != nil {
		return c.JSON(http.StatusInternalServerError, utils.ResponseDetailOutput(false, http.StatusInternalServerError, err.Error(), nil))
	}

	return c.JSON(http.StatusOK, utils.ResponseDetailOutput(true, http.StatusCreated, "Batch added successfully", newBatch))
}

func (t *AdminBatchSidangHandler) GetBatchSidang(c echo.Context) error {
	listGroupLimit, err := t.batchSidangUsecase.GetBatchSidang()
	if err != nil {
		return c.JSON(http.StatusBadRequest, utils.ResponseDetailOutput(false, http.StatusBadRequest, err.Error(), nil))
	}

	return c.JSON(http.StatusOK, utils.ResponseDetailOutput(true, http.StatusOK, "Batch Sidang successfully retreived", listGroupLimit))
}

func (t *AdminBatchSidangHandler) DeleteBatch(c echo.Context) error {
	idBatch := c.QueryParam("id")
	listGroupLimit, err := t.batchSidangUsecase.DeleteBatchSidang(idBatch)
	if err != nil {
		return c.JSON(http.StatusBadRequest, utils.ResponseDetailOutput(false, http.StatusBadRequest, err.Error(), nil))
	}

	return c.JSON(http.StatusOK, utils.ResponseDetailOutput(true, http.StatusOK, "Batch sidang successfully deleted", listGroupLimit))
}
